This Python library provides the user with some tools useful to automate coding of repetitive tasks.

Version 1.0.0

- Creation module switch.py: Contains the class Switch, allowing the user to skip defining a switch structure.

